#
# spec file for package python-managesieve
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2009 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define oname  managesieve
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-managesieve
Version:        0.7.1
Release:        1.11
Summary:        Python Module Implementing the ManageSieve Protocol
License:        GPL-3.0-or-later AND Python-2.0
Group:          Development/Libraries/Python
URL:            https://managesieve.readthedocs.io/
Source:         https://gitlab.com/htgoebel/managesieve/-/archive/v%{version}/managesieve-v%{version}.tar.bz2
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun):update-alternatives
# provides same binary: /usr/bin/sieveshell
Conflicts:      perl-Cyrus-SIEVE-managesieve
BuildArch:      noarch
%python_subpackages

%description
python-managesieve is a Python module implementing the ManageSieve client
protocol. It also includes an user application (the interactive sieveshell).

%prep
%setup -q -n %{oname}-v%{version}
touch test/__init__.py
# Fix URL
sed -i 's|http://packages.python.org/managesieve|%{url}|' setup.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/sieveshell

%check
%pytest

%post
%python_install_alternative sieveshell

%postun
%python_uninstall_alternative sieveshell

%files %{python_files}
%doc README.txt
%{_bindir}/sieveshell-%{python_bin_suffix}
%python_alternative %{_bindir}/sieveshell
%{python_sitelib}/*

%changelog
* Thu Sep  2 2021 pgajdos@suse.com
- version update to 0.7.1
  0.7.1 (2021-03-11)
  - -----------------
  :managesieve:
  - Actually raise debug-only exceptions instead of jsut returning them.
  - Fix invalid string-escape in docstring.
  - Some minor clean-up.
  :sieveshell:
  - Some minor clean-up.
  0.7 (2021-03-05)
  - ---------------
  :sieveshell:
  - For ``get`` and ``put`` expand ``~`` and ``~user`` constructions in
    `filename` . For ``put``, if script-name is not given, the file's
    basename is used.
  :managesieve:
  - Fix error when constructing debug error message.
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Feb 20 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add conflict with perl-Cyrus-SIEVE-managesieve which
  provides the same binary
* Fri Dec 14 2018 Marcus Rueckert <mrueckert@suse.de>
- update to version 0.6 (boo#1119567)
  - general
  - Add support for Python 3. Minimum required Python version is
    now Python 2.7.
  - Documentation is extended and includes API documentation.
  - sieveshell
  - Security fix: No longer leak environment variable
    SIEVE_PASSWORD when displaying usage help.
  - Per default enforce secure transport. Suggested by Jan
    Zerebecki.
  - Add possibility to use username/password from the .netrc
    file.  The order is: command line options -> environment
    variables -> .netrc file -> ask user. Thanks to Grégoire
    Détrez.
  - managesieve
  - Fail if TLS is requested, but server doesn't support TLS.
    Suggested by Jan Zerebecki.
  - project
  - Rework and enhance test-suite. Thanks to Matěj Cepl for
    nudging to proper pytest integration.
  - Lots if internal cleanup.
- drop python-managesieve-remove-ez_setup.patch
- enable python3 support
  - unversioned script will be in the python3 package
- use gitlab tarball
* Wed Aug 29 2018 tchvatal@suse.com
- Make sure to pull in full python with SSL support on python2
* Fri Jun 15 2018 toddrme2178@gmail.com
- Doesn't need python-devel at build time.
* Mon May 28 2018 mcepl@suse.com
- Clean SPEC with spec-cleaner (unfortunately py3k still switched off)
- Enable tests
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Mon Jul 13 2015 nemysis@gmx.ch
- license update: GPL-3.0+ No indication that this is GPL-3.0 (only)
- Change Url from PyPI to https://pythonhosted.org/managesieve/
- Use %%{oname} instead of managesieve
- Add sed, Fix URL
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sun Mar 24 2013 gber@opensuse.org
- update to version 0.5
  - sieveshell:
  - Changed default port for the MANAGESIEVE protocol to 4190 as
    proposed by RFC 5804. Thanks to Guido Berhoerster for
    submitting the patch.
  - Added option --port. Thanks to Damien Aumaitre for submitting
    the patch and to Guido Berhoerster for an enhancement.
  - Added option --verbose for controlling debug output in
    managesieve. May be given several times to increase
    verbosity.
  - managesieve
  - Switched to Python standard logging system. This introduces a
    minor interface change: MANAGESIEVE.debug and global Debug
    are gone. See source for information about debugging log
    levels.
- remove obsolete python-managesieve-add-port-to-sieveshell.patch
  and python-managesieve-default-port.patch
- sieveshell is now licensed under GPL-3.0
- added python-managesieve-remove-ez_setup.patch in order to remove
  unnecessary ez_setup usage
* Sun Mar 24 2013 gber@opensuse.org
- add python-managesieve-add-port-to-sieveshell.patch which adds
  a --port option to sieveshell for overriding the default port
  (bnc#811230)
- add python-managesieve-default-port.patch which changes the
  default port to 4190 as specified by RFC 5804
- update metadata
* Tue Jan 17 2012 saschpe@suse.de
- Update license to "GPL-2.0+ and Python-2.0" (bnc#741277)
* Thu Jan 12 2012 saschpe@suse.de
- Spec file cleanup:
  * BuildRequire python-distribute instead of setuptools
  * Removed %%clean section (has sane default)
  * Removed authors from description
  * Ran spec-cleaner
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Fri Nov 26 2010 gber@opensuse.org
- added separate changelog
* Fri Jan 22 2010 guido+opensuse.org@berhoerster.name
- Specified build dependencies more precisely
* Thu Jan  7 2010 guido+opensuse.org@berhoerster.name
- Update to version 0.4.2
  - includes the fix for socket.ssl deprecation warnings
* Wed Dec 30 2009 guido+opensuse.org@berhoerster.name
- Added patch to fix socket.ssl deprecation warnings on Python
  >= 2.6
* Thu Dec 24 2009 guido+opensuse.org@berhoerster.name
- initial packaging of python-managesieve
